import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface IControlDeployerInterface extends utils.Interface {
    functions: {
        "deployControl(uint256,address,string)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "deployControl", values: [BigNumberish, string, string]): string;
    decodeFunctionResult(functionFragment: "deployControl", data: BytesLike): Result;
    events: {
        "DeployedControl(address,address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "DeployedControl"): EventFragment;
}
export declare type DeployedControlEvent = TypedEvent<[
    string,
    string,
    string
], {
    registry: string;
    deployer: string;
    control: string;
}>;
export declare type DeployedControlEventFilter = TypedEventFilter<DeployedControlEvent>;
export interface IControlDeployer extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IControlDeployerInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        deployControl(nonce: BigNumberish, deployer: string, uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    deployControl(nonce: BigNumberish, deployer: string, uri: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        deployControl(nonce: BigNumberish, deployer: string, uri: string, overrides?: CallOverrides): Promise<string>;
    };
    filters: {
        "DeployedControl(address,address,address)"(registry?: string | null, deployer?: string | null, control?: string | null): DeployedControlEventFilter;
        DeployedControl(registry?: string | null, deployer?: string | null, control?: string | null): DeployedControlEventFilter;
    };
    estimateGas: {
        deployControl(nonce: BigNumberish, deployer: string, uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        deployControl(nonce: BigNumberish, deployer: string, uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
