import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export declare type ListingStruct = {
    listingId: BigNumberish;
    seller: string;
    assetContract: string;
    tokenId: BigNumberish;
    quantity: BigNumberish;
    currency: string;
    pricePerToken: BigNumberish;
    saleStart: BigNumberish;
    saleEnd: BigNumberish;
    tokensPerBuyer: BigNumberish;
    tokenType: BigNumberish;
};
export declare type ListingStructOutput = [
    BigNumber,
    string,
    string,
    BigNumber,
    BigNumber,
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    number
] & {
    listingId: BigNumber;
    seller: string;
    assetContract: string;
    tokenId: BigNumber;
    quantity: BigNumber;
    currency: string;
    pricePerToken: BigNumber;
    saleStart: BigNumber;
    saleEnd: BigNumber;
    tokensPerBuyer: BigNumber;
    tokenType: number;
};
export interface MarketInterface extends utils.Interface {
    functions: {
        "DEFAULT_ADMIN_ROLE()": FunctionFragment;
        "LISTER_ROLE()": FunctionFragment;
        "PAUSER_ROLE()": FunctionFragment;
        "_contractURI()": FunctionFragment;
        "addToListing(uint256,uint256)": FunctionFragment;
        "boughtFromListing(uint256,address)": FunctionFragment;
        "buy(uint256,uint256)": FunctionFragment;
        "contractURI()": FunctionFragment;
        "getAllListings()": FunctionFragment;
        "getListing(uint256)": FunctionFragment;
        "getListingsByAsset(address,uint256)": FunctionFragment;
        "getListingsByAssetContract(address)": FunctionFragment;
        "getListingsBySeller(address)": FunctionFragment;
        "getRoleAdmin(bytes32)": FunctionFragment;
        "getRoleMember(bytes32,uint256)": FunctionFragment;
        "getRoleMemberCount(bytes32)": FunctionFragment;
        "grantRole(bytes32,address)": FunctionFragment;
        "hasRole(bytes32,address)": FunctionFragment;
        "isTrustedForwarder(address)": FunctionFragment;
        "list(address,uint256,address,uint256,uint256,uint256,uint256,uint256)": FunctionFragment;
        "listings(uint256)": FunctionFragment;
        "marketFeeBps()": FunctionFragment;
        "multicall(bytes[])": FunctionFragment;
        "onERC1155BatchReceived(address,address,uint256[],uint256[],bytes)": FunctionFragment;
        "onERC1155Received(address,address,uint256,uint256,bytes)": FunctionFragment;
        "onERC721Received(address,address,uint256,bytes)": FunctionFragment;
        "paused()": FunctionFragment;
        "renounceRole(bytes32,address)": FunctionFragment;
        "restrictedListerRoleOnly()": FunctionFragment;
        "revokeRole(bytes32,address)": FunctionFragment;
        "setContractURI(string)": FunctionFragment;
        "setMarketFeeBps(uint128)": FunctionFragment;
        "setRestrictedListerRoleOnly(bool)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
        "totalListings()": FunctionFragment;
        "unlist(uint256,uint256)": FunctionFragment;
        "updateListingParams(uint256,uint256,address,uint256,uint256,uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "DEFAULT_ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "LISTER_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "PAUSER_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "_contractURI", values?: undefined): string;
    encodeFunctionData(functionFragment: "addToListing", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "boughtFromListing", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "buy", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "contractURI", values?: undefined): string;
    encodeFunctionData(functionFragment: "getAllListings", values?: undefined): string;
    encodeFunctionData(functionFragment: "getListing", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getListingsByAsset", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getListingsByAssetContract", values: [string]): string;
    encodeFunctionData(functionFragment: "getListingsBySeller", values: [string]): string;
    encodeFunctionData(functionFragment: "getRoleAdmin", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getRoleMember", values: [BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getRoleMemberCount", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "grantRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "hasRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "isTrustedForwarder", values: [string]): string;
    encodeFunctionData(functionFragment: "list", values: [
        string,
        BigNumberish,
        string,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish
    ]): string;
    encodeFunctionData(functionFragment: "listings", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "marketFeeBps", values?: undefined): string;
    encodeFunctionData(functionFragment: "multicall", values: [BytesLike[]]): string;
    encodeFunctionData(functionFragment: "onERC1155BatchReceived", values: [string, string, BigNumberish[], BigNumberish[], BytesLike]): string;
    encodeFunctionData(functionFragment: "onERC1155Received", values: [string, string, BigNumberish, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "onERC721Received", values: [string, string, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "paused", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "restrictedListerRoleOnly", values?: undefined): string;
    encodeFunctionData(functionFragment: "revokeRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "setContractURI", values: [string]): string;
    encodeFunctionData(functionFragment: "setMarketFeeBps", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRestrictedListerRoleOnly", values: [boolean]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "totalListings", values?: undefined): string;
    encodeFunctionData(functionFragment: "unlist", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "updateListingParams", values: [
        BigNumberish,
        BigNumberish,
        string,
        BigNumberish,
        BigNumberish,
        BigNumberish
    ]): string;
    decodeFunctionResult(functionFragment: "DEFAULT_ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "LISTER_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "PAUSER_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "_contractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addToListing", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "boughtFromListing", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "buy", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAllListings", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getListing", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getListingsByAsset", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getListingsByAssetContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getListingsBySeller", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleMember", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleMemberCount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "grantRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hasRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isTrustedForwarder", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "list", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "listings", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "marketFeeBps", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "multicall", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onERC1155BatchReceived", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onERC1155Received", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onERC721Received", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "paused", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "restrictedListerRoleOnly", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "revokeRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setContractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setMarketFeeBps", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRestrictedListerRoleOnly", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalListings", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unlist", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateListingParams", data: BytesLike): Result;
    events: {
        "ListingUpdate(address,uint256,tuple)": EventFragment;
        "MarketFeeUpdate(uint128)": EventFragment;
        "NewListing(address,address,uint256,tuple)": EventFragment;
        "NewSale(address,address,uint256,address,uint256,tuple)": EventFragment;
        "Paused(address)": EventFragment;
        "RestrictedListerRoleUpdated(bool)": EventFragment;
        "RoleAdminChanged(bytes32,bytes32,bytes32)": EventFragment;
        "RoleGranted(bytes32,address,address)": EventFragment;
        "RoleRevoked(bytes32,address,address)": EventFragment;
        "Unpaused(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ListingUpdate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "MarketFeeUpdate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewListing"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewSale"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Paused"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RestrictedListerRoleUpdated"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleAdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleGranted"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleRevoked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Unpaused"): EventFragment;
}
export declare type ListingUpdateEvent = TypedEvent<[
    string,
    BigNumber,
    ListingStructOutput
], {
    seller: string;
    listingId: BigNumber;
    listing: ListingStructOutput;
}>;
export declare type ListingUpdateEventFilter = TypedEventFilter<ListingUpdateEvent>;
export declare type MarketFeeUpdateEvent = TypedEvent<[
    BigNumber
], {
    newFee: BigNumber;
}>;
export declare type MarketFeeUpdateEventFilter = TypedEventFilter<MarketFeeUpdateEvent>;
export declare type NewListingEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    ListingStructOutput
], {
    assetContract: string;
    seller: string;
    listingId: BigNumber;
    listing: ListingStructOutput;
}>;
export declare type NewListingEventFilter = TypedEventFilter<NewListingEvent>;
export declare type NewSaleEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    string,
    BigNumber,
    ListingStructOutput
], {
    assetContract: string;
    seller: string;
    listingId: BigNumber;
    buyer: string;
    quantity: BigNumber;
    listing: ListingStructOutput;
}>;
export declare type NewSaleEventFilter = TypedEventFilter<NewSaleEvent>;
export declare type PausedEvent = TypedEvent<[string], {
    account: string;
}>;
export declare type PausedEventFilter = TypedEventFilter<PausedEvent>;
export declare type RestrictedListerRoleUpdatedEvent = TypedEvent<[
    boolean
], {
    restricted: boolean;
}>;
export declare type RestrictedListerRoleUpdatedEventFilter = TypedEventFilter<RestrictedListerRoleUpdatedEvent>;
export declare type RoleAdminChangedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    previousAdminRole: string;
    newAdminRole: string;
}>;
export declare type RoleAdminChangedEventFilter = TypedEventFilter<RoleAdminChangedEvent>;
export declare type RoleGrantedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
export declare type RoleGrantedEventFilter = TypedEventFilter<RoleGrantedEvent>;
export declare type RoleRevokedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
export declare type RoleRevokedEventFilter = TypedEventFilter<RoleRevokedEvent>;
export declare type UnpausedEvent = TypedEvent<[string], {
    account: string;
}>;
export declare type UnpausedEventFilter = TypedEventFilter<UnpausedEvent>;
export interface Market extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: MarketInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        LISTER_ROLE(overrides?: CallOverrides): Promise<[string]>;
        PAUSER_ROLE(overrides?: CallOverrides): Promise<[string]>;
        _contractURI(overrides?: CallOverrides): Promise<[string]>;
        addToListing(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        boughtFromListing(arg0: BigNumberish, arg1: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        buy(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        contractURI(overrides?: CallOverrides): Promise<[string]>;
        getAllListings(overrides?: CallOverrides): Promise<[
            ListingStructOutput[]
        ] & {
            allListings: ListingStructOutput[];
        }>;
        getListing(_listingId: BigNumberish, overrides?: CallOverrides): Promise<[ListingStructOutput] & {
            listing: ListingStructOutput;
        }>;
        getListingsByAsset(_assetContract: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<[
            ListingStructOutput[]
        ] & {
            tokenListings: ListingStructOutput[];
        }>;
        getListingsByAssetContract(_assetContract: string, overrides?: CallOverrides): Promise<[
            ListingStructOutput[]
        ] & {
            tokenListings: ListingStructOutput[];
        }>;
        getListingsBySeller(_seller: string, overrides?: CallOverrides): Promise<[
            ListingStructOutput[]
        ] & {
            sellerListings: ListingStructOutput[];
        }>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<[BigNumber]>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<[boolean]>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<[boolean]>;
        list(_assetContract: string, _tokenId: BigNumberish, _currency: string, _pricePerToken: BigNumberish, _quantity: BigNumberish, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        listings(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            string,
            string,
            BigNumber,
            BigNumber,
            string,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber,
            number
        ] & {
            listingId: BigNumber;
            seller: string;
            assetContract: string;
            tokenId: BigNumber;
            quantity: BigNumber;
            currency: string;
            pricePerToken: BigNumber;
            saleStart: BigNumber;
            saleEnd: BigNumber;
            tokensPerBuyer: BigNumber;
            tokenType: number;
        }>;
        marketFeeBps(overrides?: CallOverrides): Promise<[BigNumber]>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        onERC1155BatchReceived(arg0: string, arg1: string, arg2: BigNumberish[], arg3: BigNumberish[], arg4: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        onERC1155Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BigNumberish, arg4: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        onERC721Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        paused(overrides?: CallOverrides): Promise<[boolean]>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        restrictedListerRoleOnly(overrides?: CallOverrides): Promise<[boolean]>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setContractURI(_URI: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setMarketFeeBps(feeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRestrictedListerRoleOnly(restricted: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
        totalListings(overrides?: CallOverrides): Promise<[BigNumber]>;
        unlist(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateListingParams(_listingId: BigNumberish, _pricePerToken: BigNumberish, _currency: string, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    LISTER_ROLE(overrides?: CallOverrides): Promise<string>;
    PAUSER_ROLE(overrides?: CallOverrides): Promise<string>;
    _contractURI(overrides?: CallOverrides): Promise<string>;
    addToListing(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    boughtFromListing(arg0: BigNumberish, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
    buy(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    contractURI(overrides?: CallOverrides): Promise<string>;
    getAllListings(overrides?: CallOverrides): Promise<ListingStructOutput[]>;
    getListing(_listingId: BigNumberish, overrides?: CallOverrides): Promise<ListingStructOutput>;
    getListingsByAsset(_assetContract: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<ListingStructOutput[]>;
    getListingsByAssetContract(_assetContract: string, overrides?: CallOverrides): Promise<ListingStructOutput[]>;
    getListingsBySeller(_seller: string, overrides?: CallOverrides): Promise<ListingStructOutput[]>;
    getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
    getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<string>;
    getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    grantRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
    isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<boolean>;
    list(_assetContract: string, _tokenId: BigNumberish, _currency: string, _pricePerToken: BigNumberish, _quantity: BigNumberish, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    listings(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        string,
        string,
        BigNumber,
        BigNumber,
        string,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        number
    ] & {
        listingId: BigNumber;
        seller: string;
        assetContract: string;
        tokenId: BigNumber;
        quantity: BigNumber;
        currency: string;
        pricePerToken: BigNumber;
        saleStart: BigNumber;
        saleEnd: BigNumber;
        tokensPerBuyer: BigNumber;
        tokenType: number;
    }>;
    marketFeeBps(overrides?: CallOverrides): Promise<BigNumber>;
    multicall(data: BytesLike[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    onERC1155BatchReceived(arg0: string, arg1: string, arg2: BigNumberish[], arg3: BigNumberish[], arg4: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    onERC1155Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BigNumberish, arg4: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    onERC721Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BytesLike, overrides?: CallOverrides): Promise<string>;
    paused(overrides?: CallOverrides): Promise<boolean>;
    renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    restrictedListerRoleOnly(overrides?: CallOverrides): Promise<boolean>;
    revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setContractURI(_URI: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setMarketFeeBps(feeBps: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRestrictedListerRoleOnly(restricted: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    totalListings(overrides?: CallOverrides): Promise<BigNumber>;
    unlist(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateListingParams(_listingId: BigNumberish, _pricePerToken: BigNumberish, _currency: string, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        LISTER_ROLE(overrides?: CallOverrides): Promise<string>;
        PAUSER_ROLE(overrides?: CallOverrides): Promise<string>;
        _contractURI(overrides?: CallOverrides): Promise<string>;
        addToListing(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: CallOverrides): Promise<void>;
        boughtFromListing(arg0: BigNumberish, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        buy(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: CallOverrides): Promise<void>;
        contractURI(overrides?: CallOverrides): Promise<string>;
        getAllListings(overrides?: CallOverrides): Promise<ListingStructOutput[]>;
        getListing(_listingId: BigNumberish, overrides?: CallOverrides): Promise<ListingStructOutput>;
        getListingsByAsset(_assetContract: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<ListingStructOutput[]>;
        getListingsByAssetContract(_assetContract: string, overrides?: CallOverrides): Promise<ListingStructOutput[]>;
        getListingsBySeller(_seller: string, overrides?: CallOverrides): Promise<ListingStructOutput[]>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<string>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<boolean>;
        list(_assetContract: string, _tokenId: BigNumberish, _currency: string, _pricePerToken: BigNumberish, _quantity: BigNumberish, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: CallOverrides): Promise<void>;
        listings(arg0: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            string,
            string,
            BigNumber,
            BigNumber,
            string,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber,
            number
        ] & {
            listingId: BigNumber;
            seller: string;
            assetContract: string;
            tokenId: BigNumber;
            quantity: BigNumber;
            currency: string;
            pricePerToken: BigNumber;
            saleStart: BigNumber;
            saleEnd: BigNumber;
            tokensPerBuyer: BigNumber;
            tokenType: number;
        }>;
        marketFeeBps(overrides?: CallOverrides): Promise<BigNumber>;
        multicall(data: BytesLike[], overrides?: CallOverrides): Promise<string[]>;
        onERC1155BatchReceived(arg0: string, arg1: string, arg2: BigNumberish[], arg3: BigNumberish[], arg4: BytesLike, overrides?: CallOverrides): Promise<string>;
        onERC1155Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BigNumberish, arg4: BytesLike, overrides?: CallOverrides): Promise<string>;
        onERC721Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BytesLike, overrides?: CallOverrides): Promise<string>;
        paused(overrides?: CallOverrides): Promise<boolean>;
        renounceRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        restrictedListerRoleOnly(overrides?: CallOverrides): Promise<boolean>;
        revokeRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        setContractURI(_URI: string, overrides?: CallOverrides): Promise<void>;
        setMarketFeeBps(feeBps: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setRestrictedListerRoleOnly(restricted: boolean, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
        totalListings(overrides?: CallOverrides): Promise<BigNumber>;
        unlist(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: CallOverrides): Promise<void>;
        updateListingParams(_listingId: BigNumberish, _pricePerToken: BigNumberish, _currency: string, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ListingUpdate(address,uint256,tuple)"(seller?: string | null, listingId?: BigNumberish | null, listing?: null): ListingUpdateEventFilter;
        ListingUpdate(seller?: string | null, listingId?: BigNumberish | null, listing?: null): ListingUpdateEventFilter;
        "MarketFeeUpdate(uint128)"(newFee?: null): MarketFeeUpdateEventFilter;
        MarketFeeUpdate(newFee?: null): MarketFeeUpdateEventFilter;
        "NewListing(address,address,uint256,tuple)"(assetContract?: string | null, seller?: string | null, listingId?: BigNumberish | null, listing?: null): NewListingEventFilter;
        NewListing(assetContract?: string | null, seller?: string | null, listingId?: BigNumberish | null, listing?: null): NewListingEventFilter;
        "NewSale(address,address,uint256,address,uint256,tuple)"(assetContract?: string | null, seller?: string | null, listingId?: BigNumberish | null, buyer?: null, quantity?: null, listing?: null): NewSaleEventFilter;
        NewSale(assetContract?: string | null, seller?: string | null, listingId?: BigNumberish | null, buyer?: null, quantity?: null, listing?: null): NewSaleEventFilter;
        "Paused(address)"(account?: null): PausedEventFilter;
        Paused(account?: null): PausedEventFilter;
        "RestrictedListerRoleUpdated(bool)"(restricted?: null): RestrictedListerRoleUpdatedEventFilter;
        RestrictedListerRoleUpdated(restricted?: null): RestrictedListerRoleUpdatedEventFilter;
        "RoleAdminChanged(bytes32,bytes32,bytes32)"(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        RoleAdminChanged(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        "RoleGranted(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        RoleGranted(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        "RoleRevoked(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        RoleRevoked(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        "Unpaused(address)"(account?: null): UnpausedEventFilter;
        Unpaused(account?: null): UnpausedEventFilter;
    };
    estimateGas: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        LISTER_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        PAUSER_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        _contractURI(overrides?: CallOverrides): Promise<BigNumber>;
        addToListing(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        boughtFromListing(arg0: BigNumberish, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        buy(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        contractURI(overrides?: CallOverrides): Promise<BigNumber>;
        getAllListings(overrides?: CallOverrides): Promise<BigNumber>;
        getListing(_listingId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getListingsByAsset(_assetContract: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getListingsByAssetContract(_assetContract: string, overrides?: CallOverrides): Promise<BigNumber>;
        getListingsBySeller(_seller: string, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<BigNumber>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<BigNumber>;
        list(_assetContract: string, _tokenId: BigNumberish, _currency: string, _pricePerToken: BigNumberish, _quantity: BigNumberish, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        listings(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        marketFeeBps(overrides?: CallOverrides): Promise<BigNumber>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        onERC1155BatchReceived(arg0: string, arg1: string, arg2: BigNumberish[], arg3: BigNumberish[], arg4: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        onERC1155Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BigNumberish, arg4: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        onERC721Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        paused(overrides?: CallOverrides): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        restrictedListerRoleOnly(overrides?: CallOverrides): Promise<BigNumber>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setContractURI(_URI: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setMarketFeeBps(feeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRestrictedListerRoleOnly(restricted: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        totalListings(overrides?: CallOverrides): Promise<BigNumber>;
        unlist(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateListingParams(_listingId: BigNumberish, _pricePerToken: BigNumberish, _currency: string, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        LISTER_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        PAUSER_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        _contractURI(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        addToListing(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        boughtFromListing(arg0: BigNumberish, arg1: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        buy(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        contractURI(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getAllListings(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getListing(_listingId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getListingsByAsset(_assetContract: string, _tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getListingsByAssetContract(_assetContract: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getListingsBySeller(_seller: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleMember(role: BytesLike, index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleMemberCount(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isTrustedForwarder(forwarder: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        list(_assetContract: string, _tokenId: BigNumberish, _currency: string, _pricePerToken: BigNumberish, _quantity: BigNumberish, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        listings(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        marketFeeBps(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        multicall(data: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        onERC1155BatchReceived(arg0: string, arg1: string, arg2: BigNumberish[], arg3: BigNumberish[], arg4: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        onERC1155Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BigNumberish, arg4: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        onERC721Received(arg0: string, arg1: string, arg2: BigNumberish, arg3: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        paused(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        restrictedListerRoleOnly(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setContractURI(_URI: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setMarketFeeBps(feeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRestrictedListerRoleOnly(restricted: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        totalListings(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        unlist(_listingId: BigNumberish, _quantity: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateListingParams(_listingId: BigNumberish, _pricePerToken: BigNumberish, _currency: string, _tokensPerBuyer: BigNumberish, _secondsUntilStart: BigNumberish, _secondsUntilEnd: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
